@@ -51,6 +51,10 @@ class User(object):
     def uid(self):
         return self.pw.pw_uid
 
+    @property
+    def gid(self):
+        return self.pw.pw_gid
+
     @property
     def name(self):
         return self.pw.pw_name
